/* Pango
 * pangoatsui-private.h:
 *
 * Copyright (C) 2003 Red Hat Software
 * Copyright (C) 2005-2007 Imendio AB
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __PANGORISCOS_PRIVATE_H__
#define __PANGORISCOS_PRIVATE_H__

#include <pango/pango-fontmap.h>
#include <pango/pango-context.h>
#include "pangoriscos.h"

G_BEGIN_DECLS

#define PANGO_TYPE_RISCOS_FONT_MAP             (pango_riscos_font_map_get_type ())
#define PANGO_RISCOS_FONT_MAP(object)          (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_RISCOS_FONT_MAP, PangoRISCOSFontMap))
#define PANGO_RISCOS_IS_FONT_MAP(object)       (G_TYPE_CHECK_INSTANCE_TYPE ((object), PANGO_TYPE_RISCOS_FONT_MAP))
#define PANGO_RISCOS_FONT_MAP_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), PANGO_TYPE_RISCOS_FONT_MAP, PangoRISCOSFontMapClass))
#define PANGO_IS_RISCOS_FONT_MAP_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), PANGO_TYPE_RISCOS_FONT_MAP))
#define PANGO_RISCOS_FONT_MAP_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), PANGO_TYPE_RISCOS_FONT_MAP, PangoRISCOSFontMapClass))


typedef struct _PangoRISCOSFamily       PangoRISCOSFamily;
typedef struct _PangoRISCOSFace         PangoRISCOSFace;

typedef struct _PangoRISCOSFontMap      PangoRISCOSFontMap;
typedef struct _PangoRISCOSFontMapClass PangoRISCOSFontMapClass;

struct _PangoRISCOSFontMap
{
  PangoFontMap parent_instance;

  GHashTable *font_hash;

  GHashTable *families;
};

struct _PangoRISCOSFontMapClass
{
  PangoFontMapClass parent_class;

  gconstpointer (*context_key_get)   (PangoRISCOSFontMap             *riscosfontmap,
				      PangoContext               *context);
  gpointer     (*context_key_copy)   (PangoRISCOSFontMap             *riscosfontmap,
				      gconstpointer               key);
  void         (*context_key_free)   (PangoRISCOSFontMap             *riscosfontmap,
				      gpointer                    key);
  guint32      (*context_key_hash)   (PangoRISCOSFontMap             *riscosfontmap,
				      gconstpointer               key);
  gboolean     (*context_key_equal)  (PangoRISCOSFontMap             *riscosfontmap,
				      gconstpointer               key_a,
				      gconstpointer               key_b);

  PangoRISCOSFont * (* create_font)   (PangoRISCOSFontMap          *fontmap,
				      PangoContext               *context,
				      PangoRISCOSFace             *face,
				      const PangoFontDescription *desc);
};


GType                 pango_riscos_font_map_get_type          (void) G_GNUC_CONST;

const char *          _pango_riscos_face_get_postscript_name  (PangoRISCOSFace    *face);
PangoCoverage *       _pango_riscos_face_get_coverage         (PangoRISCOSFace    *face,
                                                              PangoLanguage     *language);
gboolean              _pango_riscos_face_get_synthetic_italic (PangoRISCOSFace    *face);

void                  _pango_riscos_font_set_font_description (PangoRISCOSFont    *afont,
                                                              const PangoFontDescription *desc);
PangoFontDescription *_pango_riscos_font_get_font_description (PangoRISCOSFont    *afont);
void                  _pango_riscos_font_set_font_map         (PangoRISCOSFont    *afont,
                                                              PangoRISCOSFontMap *fontmap);
void                  _pango_riscos_font_set_face             (PangoRISCOSFont    *afont, 
                                                              PangoRISCOSFace    *aface);
PangoRISCOSFace *      _pango_riscos_font_get_face             (PangoRISCOSFont    *font);
gpointer              _pango_riscos_font_get_context_key      (PangoRISCOSFont    *afont);
void                  _pango_riscos_font_set_context_key      (PangoRISCOSFont    *afont,
                                                              gpointer           context_key);
void                  _pango_riscos_font_set_riscos_font_id     (PangoRISCOSFont    *font,
                                                              int         font_id);

G_END_DECLS

#endif /* __PANGORISCOS_H__ */
