/* Pango
 * pangatsui.c
 *
 * Copyright (C) 2005-2007 Imendio AB
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <config.h>

#include "pangoriscos.h"
#include "pangoriscos-private.h"

G_DEFINE_TYPE (PangoRISCOSFont, pango_riscos_font, PANGO_TYPE_FONT);

//typedef int PangoRISCOSFace;
//typedef int PangoRISCOSFontMap;
//typedef int PangoRISCOSFontPrivate;

struct _PangoRISCOSFontPrivate
{
  PangoRISCOSFace *face;
  PangoFontDescription *desc;
  gpointer context_key;

  int font_id;

  PangoFontMap *fontmap;
};

static void
pango_riscos_font_finalize (GObject *object)
{
  PangoRISCOSFont *afont = (PangoRISCOSFont *)object;
  PangoRISCOSFontPrivate *priv = afont->priv;

  pango_font_description_free (priv->desc);

  g_object_unref (priv->fontmap);

  G_OBJECT_CLASS (pango_riscos_font_parent_class)->finalize (object);
}

static PangoFontDescription *
pango_riscos_font_describe (PangoFont *font)
{
  PangoRISCOSFont *afont = (PangoRISCOSFont *)font;
  PangoRISCOSFontPrivate *priv = afont->priv;

  return pango_font_description_copy (priv->desc);
}

static PangoCoverage *
pango_riscos_font_get_coverage (PangoFont     *font,
	                       PangoLanguage *language)
{
  PangoRISCOSFont *afont = (PangoRISCOSFont *)font;
  PangoRISCOSFontPrivate *priv = afont->priv;

  return pango_coverage_ref (_pango_riscos_face_get_coverage (priv->face,
                                                             language));
}

static PangoEngineShape *
pango_riscos_font_find_shaper (PangoFont     *font,
			      PangoLanguage *language,
			      guint32        ch)
{
  /* FIXME: Implement */
  return NULL;
}

static PangoFontMap *
pango_riscos_font_get_font_map (PangoFont *font)
{
  PangoRISCOSFont *afont = (PangoRISCOSFont *)font;

  return afont->priv->fontmap;
}

static void
pango_riscos_font_init (PangoRISCOSFont *afont)
{
  afont->priv = G_TYPE_INSTANCE_GET_PRIVATE (afont,
                                             PANGO_TYPE_RISCOS_FONT,
                                             PangoRISCOSFontPrivate);
}

static void
pango_riscos_font_class_init (PangoRISCOSFontClass *class)
{
  GObjectClass *object_class = G_OBJECT_CLASS (class);
  PangoFontClass *font_class = PANGO_FONT_CLASS (class);

  object_class->finalize = pango_riscos_font_finalize;

  font_class->describe = pango_riscos_font_describe;
  font_class->get_coverage = pango_riscos_font_get_coverage;
  font_class->find_shaper = pango_riscos_font_find_shaper;
  font_class->get_font_map = pango_riscos_font_get_font_map;

  g_type_class_add_private (object_class, sizeof (PangoRISCOSFontPrivate));
}

void
_pango_riscos_font_set_font_description (PangoRISCOSFont             *font,
                                        const PangoFontDescription *desc)
{
  PangoRISCOSFontPrivate *priv = font->priv;

  priv->desc = pango_font_description_copy (desc);
}

PangoFontDescription *
_pango_riscos_font_get_font_description (PangoRISCOSFont *font)
{
  PangoRISCOSFontPrivate *priv = font->priv;

  return priv->desc;
}

void
_pango_riscos_font_set_font_map (PangoRISCOSFont    *font,
				 PangoRISCOSFontMap *fontmap)
{
  PangoRISCOSFontPrivate *priv = font->priv;

  g_assert (priv->fontmap == NULL);
  
  //priv->fontmap = g_object_ref (fontmap);
}

void
_pango_riscos_font_set_face (PangoRISCOSFont *afont, 
                            PangoRISCOSFace *face)
{
  PangoRISCOSFontPrivate *priv = afont->priv;

  priv->face = face;
}

PangoRISCOSFace *
_pango_riscos_font_get_face (PangoRISCOSFont *afont)
{
  PangoRISCOSFontPrivate *priv = afont->priv;

  return priv->face;
}

gpointer
_pango_riscos_font_get_context_key (PangoRISCOSFont *afont)
{
  PangoRISCOSFontPrivate *priv = afont->priv;

  return priv->context_key;
}

void
_pango_riscos_font_set_context_key (PangoRISCOSFont *afont,
                                   gpointer        context_key)
{
  PangoRISCOSFontPrivate *priv = afont->priv;

  priv->context_key = context_key;
}

void
_pango_riscos_font_set_riscos_font_id (PangoRISCOSFont *font,
                                    int      font_id)
{
  PangoRISCOSFontPrivate *priv = font->priv;

  priv->font_id = font_id;
}

/**
 * pango_riscos_font_get_atsu_font_id:
 * @font: A #PangoRISCOSFont
 *
 * Returns the ATSUFontID of a font.
 *
 * Return value: the ATSUFontID associated to @font.
 *
 * Since: 1.18
 */
int
pango_riscos_font_get_riscos_font_id (PangoRISCOSFont *font)
{
  PangoRISCOSFontPrivate *priv = font->priv;

  return priv->font_id;
}
